@@ -181,14 +181,18 @@ class Artifacts:
                     path = path.replace("\\", "/")
                 size = os.stat(local_path).st_size
                 with open(local_path, "rb") as f:
-                    digest = hashlib.md5(f.read()).hexdigest()
+                    local_file_digest = hashlib.md5(f.read()).hexdigest()
 
                 entry = self.__find_entry_by_path(local_path, path)
                 if entry:
                     entry.status = "SYNC"  # 변경이 없는 경우
+                    if entry.digest != local_file_digest:   # local의 root 경로가 바껴서 파일명은 동일하지만, 파일내용이 바뀐경우
+                        entry.local_path = local_path
+                        entry.digest = local_file_digest
+                        entry.size = size
                 else:
                     self.entry_list.append(
-                        ArtifactEntry(path, local_path, size, digest, status="ADD", lfs_yn="", repo_tag="", type="FILE",
+                        ArtifactEntry(path, local_path, size, local_file_digest, status="ADD", lfs_yn="", repo_tag="", type="FILE",
                                       metadata=""))  # 파일이 추가된 경우
 
     def __local_path_sync_for_delete(self) -> None:
