@@ -14,7 +14,6 @@ from deepdriver.sdk.data_types.run import set_run, Run, get_run
 from deepdriver.sdk.interface import interface
 
 
-
 @util.login_required
 def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Dict = None) -> Run:
     """ # 실행과 실험환경을 만드는 함수 """
@@ -54,11 +53,20 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
         for key, value in parameters_dict.items():
             key_value_dict = {
                 "key": key,
-                "value": {
-                    next(iter(value.keys())): next(iter(value.values()))
-                }
+                # "value": {
+                #     next(iter(value.keys())): next(iter(value.values()))
+                # }
             }
+            if 'range' in value.keys():
+                key_value_dict['value'] = {'range': value['range']}
+                if 'distribution' in value.keys():
+                    key_value_dict['description'] = value['distribution']
+
+            if 'values' in value.keys():
+                key_value_dict['value'] = {'values': value['values']}
+
             key_value_parameters_list.append(key_value_dict)
+
         hpo_config['parameters'] = key_value_parameters_list
 
     rsp = interface.create_hpo(exp_name, team_name, hpo_config)
@@ -86,7 +94,7 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
             elif type.lower() == "bayesian":
                 return optuna.samplers.TPESampler()
 
-        team_name_ =  team_name or  get_experiment().team_name  # team 이름이 입력되지 않은경우 run에 설정된 team 이름을 사용
+        team_name_ = team_name or get_experiment().team_name  # team 이름이 입력되지 않은경우 run에 설정된 team 이름을 사용
         try:
             optuna.create_study(study_name=team_name_ + "_" + exp_name,
                                 storage="postgresql://hpo:hpo@ce-postg.bokchi.com:5432/hpo",  # TODO : 변경예정
@@ -104,7 +112,6 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
 @util.login_required
 def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Dict = None,
             func: Callable = None, count: int = 10, artifact: Dict = None, job_count: int = 0) -> bool:
-
     result1, hpoConfig = get_hpo(exp_name=exp_name, team_name=team_name)
     result2, study = load_hpo(exp_name=exp_name, team_name=team_name)
     result3 = run_optimize(exp_name=exp_name, team_name=team_name, func=func, config=hpoConfig, count=count,
@@ -122,7 +129,7 @@ def get_hpo(exp_name: str = "", team_name: str = "") -> (bool, Dict):
 
 @util.login_required
 def load_hpo(exp_name: str = "", team_name: str = "") -> (bool, optuna.study.study.Study):
-    team_name_ =  team_name or  get_experiment().team_name
+    team_name_ = team_name or get_experiment().team_name
     try:
         study = optuna.load_study(study_name=team_name_ + "_" + exp_name,
                                   storage="postgresql://hpo:hpo@ce-postg.bokchi.com:5432/hpo")
@@ -142,20 +149,39 @@ def run_optimize(exp_name: str = "", team_name: str = "", func: Callable = None,
         deepdriver.init(exp_name=exp_name)
         get_config(trial, config)
         y = func()
-        deepdriver.log({"x": deepdriver.config.x, "y": y})
+        deepdriver.log(deepdriver.config.__dict__)
         deepdriver.finish()
         return y
 
     def get_config(trial, config):
-        # to-do config 의 parameters 내용을 조건에  따라 하기와 같은 코드로 변환
-        # {"key": "x" , "value" : {"range":[-10.0,10.0]} } 조건의 경우 하기와 같이
-        deepdriver.config.x = trial.suggest_float("x", -10, 10)
-        # {"key": "y" , "value" : {"range":[-10,10]} }조건의 경우 하기와 같이
-        # deepdriver.config.y = trial.suggest_int("x", -10, 10)
-        # {"key": "classifier" , "value" : {"values":['SVC','RandomForest']} } 조건의 경우 하기와 같이
-        ##deepdriver.config.classifier= trial.suggest_categorical('classifier', ['SVC', 'RandomForest'])
+        # config 의 parameters 내용을 조건에  따라 하기와 같은 코드로 변환
+        for item_dict in config['parameters']:
+            key: str = item_dict['key']
+            sub_key = next(iter(item_dict['value'].keys()))  # 'values' or 'range'
+            values: list = next(iter(item_dict['value'].values()))
+            suggest = None
+            if sub_key == "range":
+                if 'description' in item_dict and item_dict['description']:
+                    # 'description'(distribution)이 있는 경우
+                    if item_dict['description'] == "uniform":
+                        suggest = trial.suggest_uniform(item_dict['description'], min(values), max(values))
+                    if item_dict['description'] == "log_uniform":
+                        suggest = trial.suggest_loguniform(item_dict['description'], min(values), max(values))
+                else:
+                    if all(isinstance(x, float) for x in values):
+                        suggest = trial.suggest_float(key, min(values), max(values))
+                    if all(isinstance(x, int) for x in values):
+                        suggest = trial.suggest_int(key, min(values), max(values))
+                if suggest:
+                    exec(f'deepdriver.config.{key} = suggest')
+                else:
+                    logger.error(f"error : {item_dict}")
+            elif sub_key == "values":
+                exec(f'deepdriver.config.{key} = trial.suggest_categorical("{key}", {values})')
 
-    team_name_ =  team_name or  get_experiment().team_name
+        logger.debug(f"deepdriver.config. : {deepdriver.config.__dict__}")
+
+    team_name_ = team_name or get_experiment().team_name
     try:
         study = study.optimize(get_wrapped_func(exp_name, team_name_, func, config), n_trials=count)
     except Exception as e:
